@@ -554,7 +554,21 @@ CONTENT\r
 fn test_escape_without_source() {
     fn es2020(src: &str, expected: &str) {
         assert_eq!(
-            super::escape_without_source(src, EsVersion::Es2020, true),
+            super::escape_without_source(src, EsVersion::Es2020, true, false),
+            expected
+        )
+    }
+
+    fn es2020_nonascii(src: &str, expected: &str) {
+        assert_eq!(
+            super::escape_without_source(src, EsVersion::Es2020, true, true),
+            expected
+        )
+    }
+
+    fn es5(src: &str, expected: &str) {
+        assert_eq!(
+            super::escape_without_source(src, EsVersion::Es5, true, true),
             expected
         )
     }
@@ -576,6 +590,13 @@ fn test_escape_without_source() {
     es2020("\u{1000}", "\u{1000}");
     es2020("\u{ff}", "\\xff");
     es2020("\u{10ffff}", "\u{10ffff}");
+
+    es2020_nonascii("\u{FEFF}abc", "\\uFEFFabc");
+    es2020_nonascii("\u{10ffff}", "\\u{10FFFF}");
+
+    es5("\u{FEFF}abc", "\\uFEFFabc");
+    es5("\u{10ffff}", "\\uDBFF\\uDFFF");
+    es5("\u{FFFF}", "\\uFFFF");
 }
 
 #[test]
@@ -612,7 +633,7 @@ fn issue_1619_2() {
 #[test]
 fn issue_1619_3() {
     assert_eq!(
-        escape_without_source("\x00\x31", EsVersion::Es3, true),
+        escape_without_source("\x00\x31", EsVersion::Es3, true, false),
         "\\x001"
     );
 }
@@ -657,3 +678,22 @@ impl Write for Buf {
 fn issue_2213() {
     assert_min("a - -b * c", "a- -b*c")
 }
+
+#[test]
+fn issue3617() {
+    let from = r"// a string of all valid unicode whitespaces
+    module.exports = '\u0009\u000A\u000B\u000C\u000D\u0020\u00A0\u1680\u2000\u2001\u2002' +
+      '\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF';";
+    let expected = r#"// a string of all valid unicode whitespaces
+module.exports = '\t\n\v\f\r \xa0\u1680\u2000\u2001\u2002' + '\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF';"#;
+
+    let out = parse_then_emit(from, Default::default(), Syntax::default(), EsVersion::Es5);
+
+    dbg!(&out);
+    dbg!(&expected);
+
+    assert_eq!(
+        DebugUsingDisplay(out.trim()),
+        DebugUsingDisplay(expected.trim()),
+    );
+}
